<?php
/*********************************************************************
    class.AGENCY.php

    Agencies

    Neil Tozier <n.tozier@tmib.net>
    Copyright (c)  2010-2013 tmib.net
    http://www.tmib.net
	For use with osTicket v1.7ST

    Released under the GNU General Public License WITHOUT ANY WARRANTY.
    See LICENSE.TXT for details.

    vim: expandtab sw=4 ts=4 sts=4:
**********************************************************************/
class AGENCY {

    var $id;

    var $info;

    function AGENCY($id) {
        $this->id=0;
        $this->load($id);
    }

    function load($id=0) {

        if(!$id && !($id=$this->getId()))
            return false;

        $sql='SELECT * FROM ost_agencies WHERE id='.db_input($id);
        if(!($res=db_query($sql)) || !db_num_rows($res))
            return false;

        $this->ht=db_fetch_array($res);
        $this->id=$this->ht['id'];
        return true;
    }

    function reload() {
        return $this->load();
    }

    function getId() {
        return $this->id;
    }

    function getagency() {
        return $this->ht['agency'];
    }
        
    function getNotes() {
        return $this->ht['notes'];
    }

    function getHashtable() {
        return  $this->ht;
    }

    function getInfo() {
        return $this->getHashtable();
    }

    function isActive() {
        return ($this->ht['isenabled']);
    }

    function update($vars,&$errors) {
        
        if(!AGENCY::save($this->getId(),$vars,$errors))
            return false;

        $this->reload();

        return true;
    }

    function delete() {
        global $cfg;

        if(!$cfg || $cfg->getDefaultAGENCYId()==$this->getId())
            return false;

        $id=$this->getId();
        $sql='DELETE FROM ost_agencies WHERE id='.db_input($id).' LIMIT 1';
        if(db_query($sql) && ($num=db_affected_rows())) {
            db_query('UPDATE '.DEPT_TABLE.' SET agency=0 WHERE agency='.db_input($id));
            db_query('UPDATE '.TOPIC_TABLE.' SET agency=0 WHERE agency='.db_input($id));
            db_query('UPDATE '.TICKET_TABLE.' SET agency='.db_input($cfg->getDefaultAGENCYId()).' WHERE agency='.db_input($id));
        }

        return $num;
    }

    /** static functions **/
    function create($vars,&$errors) {
        return AGENCY::save(0,$vars,$errors);
    }

    function getAGENCYs() {

        $agencies=array();
        $sql='SELECT id, agency, isenabled FROM ost_agencies ORDER BY agency';
        if(($res=db_query($sql)) && db_num_rows($res)) {
            while($row=db_fetch_array($res))
                $agencies[$row['id']] = sprintf('%s (%d hrs - %s)',
                        $row['agency'], 
                        $row['isenabled']?'Active':'Disabled');
        }

        return $agencies;
    }


    function getIdByagency($agency) {

        $sql='SELECT id FROM ost_agencies WHERE agency='.db_input($agency);
        if(($res=db_query($sql)) && db_num_rows($res))
            list($id)=db_fetch_row($res);

        return $id;
    }

    function lookup($id) {
        return ($id && is_numeric($id) && ($sla= new AGENCY($id)) && $sla->getId()==$id)?$sla:null;
    }

    function save($id,$vars,&$errors) {
            
        if(!$vars['agency'])
            $errors['agency']='agency required';
        elseif(($sid=AGENCY::getIdByagency($vars['agency'])) && $sid!=$id)
            $errors['agency']='agency already exists';

        if($errors) return false;

        $sql=" `upDate`=NOW() ".
             ',isenabled='.db_input($vars['isenabled']).
             ',agency='.db_input($vars['agency']).
			       //',editor='.db_input($thisstaff->getUserName()).
             ',notes='.db_input($vars['notes']);

        if($id) {
            $sql='UPDATE ost_agencies SET '.$sql.' WHERE id='.db_input($id);
            if(db_query($sql))
                return true;

            $errors['err']='Unable to update AGENCY. Internal error occurred';
        }else{
            $sql='INSERT INTO ost_agencies SET '.$sql.',addDate=NOW() ';
            if(db_query($sql) && ($id=db_insert_id()))
                return $id;

            $errors['err']='Unable to add Agency. Internal error';
        }

        return false;
    }
}
?>
